//--------------------------------------------------------------
// File     : stm32_ub_spi2.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F7_UB_SPI2_H
#define __STM32F7_UB_SPI2_H

//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32_ub_system.h"



//--------------------------------------------------------------
// SPI-Mode (Full-Duplex)
//--------------------------------------------------------------
typedef enum {
  SPI_MODE_0_MSB = 0,  // CPOL=0, CPHA=0 (MSB-First)
  SPI_MODE_1_MSB,      // CPOL=0, CPHA=1 (MSB-First)
  SPI_MODE_2_MSB,      // CPOL=1, CPHA=0 (MSB-First)
  SPI_MODE_3_MSB,      // CPOL=1, CPHA=1 (MSB-First)
  SPI_MODE_0_LSB,      // CPOL=0, CPHA=0 (LSB-First)
  SPI_MODE_1_LSB,      // CPOL=0, CPHA=1 (LSB-First)
  SPI_MODE_2_LSB,      // CPOL=1, CPHA=0 (LSB-First)
  SPI_MODE_3_LSB       // CPOL=1, CPHA=1 (LSB-First) 
}SPI2_Mode_t;



//--------------------------------------------------------------
// SPI-Clock
// Grundfrequenz (SPI2)= APB1 (APB1=50MHz)
// Mgliche Vorteiler = 2,4,8,16,32,64,128,256
//--------------------------------------------------------------
//#define SPI2_VORTEILER     SPI_BAUDRATEPRESCALER_2   // Frq = 25 MHz
//#define SPI2_VORTEILER     SPI_BAUDRATEPRESCALER_4   // Frq = 12.5 MHz
#define SPI2_VORTEILER     SPI_BAUDRATEPRESCALER_8   // Frq = 6.25 MHz
//#define SPI2_VORTEILER     SPI_BAUDRATEPRESCALER_16  // Frq = 3.125 MHz
//#define SPI2_VORTEILER     SPI_BAUDRATEPRESCALER_32  // Frq = 1.562 MHz
//#define SPI2_VORTEILER     SPI_BAUDRATEPRESCALER_64  // Frq = 781.2 MHz
//#define SPI2_VORTEILER     SPI_BAUDRATEPRESCALER_128 // Frq = 390.6 kHz
//#define SPI2_VORTEILER     SPI_BAUDRATEPRESCALER_256 // Frq = 195.3 kHz



//--------------------------------------------------------------
// SPI-GPIO-Pins
// moegliche Pinbelegung :
//   SCK  : [PA9, PB10, PB13, PD3, PI1]
//   MISO : [PB14, PC2, PI2]
//   MOSI : [PB15, PC1, PC3, PI3]
//--------------------------------------------------------------
#define  SPI2_SCK_PORT     GPIOI
#define  SPI2_SCK_PIN      GPIO_PIN_1

#define  SPI2_MISO_PORT    GPIOI
#define  SPI2_MISO_PIN     GPIO_PIN_2

#define  SPI2_MOSI_PORT    GPIOI
#define  SPI2_MOSI_PIN     GPIO_PIN_3



//--------------------------------------------------------------
#define  SPI2_TX_TIMEOUT   1000



//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
ErrorStatus UB_SPI2_Init(SPI2_Mode_t mode);
uint8_t UB_SPI2_SendByte(uint8_t wert);
void UB_SPI2_SendArray(uint8_t *tx_buf, uint8_t *rx_buf, uint16_t cnt);




//--------------------------------------------------------------
#endif // __STM32F7_UB_SPI2_H
