//--------------------------------------------------------------
// File     : stm32_ub_spi5.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F7_UB_SPI5_H
#define __STM32F7_UB_SPI5_H

//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32_ub_system.h"



//--------------------------------------------------------------
// SPI-Mode (Full-Duplex)
//--------------------------------------------------------------
typedef enum {
  SPI_MODE_0_MSB = 0,  // CPOL=0, CPHA=0 (MSB-First)
  SPI_MODE_1_MSB,      // CPOL=0, CPHA=1 (MSB-First)
  SPI_MODE_2_MSB,      // CPOL=1, CPHA=0 (MSB-First)
  SPI_MODE_3_MSB,      // CPOL=1, CPHA=1 (MSB-First)
  SPI_MODE_0_LSB,      // CPOL=0, CPHA=0 (LSB-First)
  SPI_MODE_1_LSB,      // CPOL=0, CPHA=1 (LSB-First)
  SPI_MODE_2_LSB,      // CPOL=1, CPHA=0 (LSB-First)
  SPI_MODE_3_LSB       // CPOL=1, CPHA=1 (LSB-First) 
}SPI5_Mode_t;



//--------------------------------------------------------------
// SPI-Clock
// Grundfrequenz (SPI5)= APB2 (APB2=100MHz)
// Mgliche Vorteiler = 2,4,8,16,32,64,128,256
//--------------------------------------------------------------
//#define SPI5_VORTEILER     SPI_BAUDRATEPRESCALER_2   // Frq = 50 MHz
//#define SPI5_VORTEILER     SPI_BAUDRATEPRESCALER_4   // Frq = 25 MHz
#define SPI5_VORTEILER     SPI_BAUDRATEPRESCALER_8   // Frq = 12,5 MHz
//#define SPI5_VORTEILER     SPI_BAUDRATEPRESCALER_16  // Frq = 6.25 MHz
//#define SPI5_VORTEILER     SPI_BAUDRATEPRESCALER_32  // Frq = 3.125 MHz
//#define SPI5_VORTEILER     SPI_BAUDRATEPRESCALER_64  // Frq = 1.562 MHz
//#define SPI5_VORTEILER     SPI_BAUDRATEPRESCALER_128 // Frq = 781.2 kHz
//#define SPI5_VORTEILER     SPI_BAUDRATEPRESCALER_256 // Frq = 390.6 kHz



//--------------------------------------------------------------
// SPI-GPIO-Pins
// moegliche Pinbelegung :
//   SCK  : [PF7, PH6]
//   MISO : [PF8, PH7]
//   MOSI : [PF9, PF11]
//--------------------------------------------------------------
#define  SPI5_SCK_PORT     GPIOF
#define  SPI5_SCK_PIN      GPIO_PIN_7

#define  SPI5_MISO_PORT    GPIOF
#define  SPI5_MISO_PIN     GPIO_PIN_8

#define  SPI5_MOSI_PORT    GPIOF
#define  SPI5_MOSI_PIN     GPIO_PIN_9



//--------------------------------------------------------------
#define  SPI5_TX_TIMEOUT   1000



//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
ErrorStatus UB_SPI5_Init(SPI5_Mode_t mode);
uint8_t UB_SPI5_SendByte(uint8_t wert);
void UB_SPI5_SendArray(uint8_t *tx_buf, uint8_t *rx_buf, uint16_t cnt);




//--------------------------------------------------------------
#endif // __STM32F7_UB_SPI5_H
